@@ -132,12 +132,16 @@ class OvsHost(linux.LinuxDevice):
         '''
         name = kwargs.get("name", "tmpname")
         command = 'ovs-vsctl add-port %s %s' %(bridge_name, name)
-        if kwargs:
-            # If there is parameters, for example type=vxlan, etc.
-            command += ' -- set interface %s' %(name)
-            for k,v in kwargs.items():
-                if (k not in ["name", "ip", "mac"]):
-                    command += ' %s=%s' %(k,v)
+
+        # parameter ip/mac is not valid, won't be included in the add-port
+        port_options = {}
+        for k,v in kwargs.items():
+            if (k not in ["name", "ip", "mac"]):
+                port_options[k] = v
+        if port_options:
+            command += ' -- set Interface %s' %(name)
+            for k,v in port_options.items():
+                command += ' %s=%s' %(k,v)
         self.cmd(command) #execut the command.
 
         #If it's a normal interface, flush it to release its original ip address.
@@ -387,31 +391,6 @@ class OvsHost(linux.LinuxDevice):
                     "priority=60000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
                     %(ip.network, ip.ip, vxlan_port))
 
-    def set_next_hop (self, bridge_name, gw, *args):
-        '''
-        Add some flows to ofproto
-        '''
-        vxlan_port = None # Get the vxlan at first.
-
-        for d in args:
-            if d.get("type", None) == "vxlan":
-                vxlan_port = self.ovs_get_interface(d["name"], "ofport")
-                break
-        for d in args:
-            if d.get("type", None) != "vxlan":
-                if ((d["mac"] not in self.macs) and (not vxlan_port)):
-                    # d is not on host, but there is no vxlan given.
-                    self.log("Error: there is no vxlan to remote device: %s!"
-                            %(d["name"]), bg_color = "red")
-                    return
-
-                self.ofctl_add_flow(bridge_name,
-                    "priority=10,ip,nw_dst=%s,action=mod_dl_src:%s,"
-                    "mod_dl_dst:%s,dec_ttl,output:%s"
-                    %(d["ip"].split("/")[0], gw["mac"], d["mac"],
-                        (d["mac"] in self.macs) and d["ofport"] or vxlan_port))
-
-
     def del_br (self, *args, **kwargs):
         '''
         Delete the bridge and all the connected devices(containers).
@@ -501,35 +480,37 @@ class OvsHost(linux.LinuxDevice):
                     self.cmd('ovs-ofctl add-flow %s %s' %(bridge_name, l))
         return None
 
-    def ping_test (self, src, dst):
+    def ping_test (self, src, dsts):
         '''
         Add some flows to ofproto
         '''
-        dstip = ipaddress.ip_interface(dst["ip"])
-        if src["type"] == "container":
-            srcip = ipaddress.ip_interface(src["ip"])
-            result = self.cmd('docker exec -it %s ping %s -c 1'
-                    %(src["name"], dstip.ip))
-        elif src["type"] == "vm":
-            srcip = ipaddress.ip_interface(src["port"][1]["ip"])
-            if dstip.ip not in srcip.network:
-                # warning to configure the route.
-                self.log("WARNING: don't forget to configure route to %s!"
-                        %(dstip.ip), bg_color = "purple")
-            result = self.cmd('sshpass -p %s ssh %s@%s ping -c 1 %s'
-                %(src["password"], src["username"],
-                    src["port"][0]["ip"].split("/")[0], dstip.ip))
-        else:
-            return False
+        dsts = dsts if (isinstance(dsts, list)) else [dsts]
+        for dst in dsts:
+            dstip = ipaddress.ip_interface(dst["ip"])
+            if src["type"] == "container":
+                srcip = ipaddress.ip_interface(src["ip"])
+                result = self.cmd('docker exec -it %s ping %s -c 1'
+                        %(src["name"], dstip.ip))
+            elif src["type"] == "vm":
+                srcip = ipaddress.ip_interface(src["port"][1]["ip"])
+                if dstip.ip not in srcip.network:
+                    # warning to configure the route.
+                    self.log("WARNING: don't forget to configure route to %s!"
+                            %(dstip.ip), bg_color = "purple")
+                result = self.cmd('sshpass -p %s ssh %s@%s ping -c 1 %s'
+                    %(src["password"], src["username"],
+                        src["port"][0]["ip"].split("/")[0], dstip.ip))
+            else:
+                self.log("ERROR: don't support the type %s!"
+                        %(src["type"]), bg_color = "purple")
+                return False
 
-        if "received, 0% packet loss," in result:
-            self.log("PASS: %s ping %s, %s -> %s!" %(src["name"], dst["name"],
-                srcip.ip, dstip.ip), bg_color = "green")
-            return True
-        else:
-            self.log("FAIL: %s ping %s, %s -> %s!" %(src["name"], dst["name"],
-                srcip.ip, dstip.ip), bg_color = "red")
-            return False
+            if "received, 0% packet loss," in result:
+                self.log("PASS: %s ping %s, %s -> %s!" %(src["name"], dst["name"],
+                    srcip.ip, dstip.ip), bg_color = "green")
+            else:
+                self.log("FAIL: %s ping %s, %s -> %s!" %(src["name"], dst["name"],
+                    srcip.ip, dstip.ip), bg_color = "red")
 
 if __name__ == '__main__':
     '''
